@@ -1,10 +1,11 @@
 """ Exported Compressed File api
 """
+
+from core_main_app.access_control.decorators import access_control
+from core_exporters_app.access_control.api import can_read
 from core_exporters_app.components.exported_compressed_file.models import (
     ExportedCompressedFile,
 )
-from core_exporters_app.access_control.api import can_read
-from core_main_app.access_control.decorators import access_control
 
 
 @access_control(can_read)
@@ -13,6 +14,7 @@ def get_by_id(exported_compressed_file_id, user):
 
     Args:
         exported_compressed_file_id: id
+         user:
 
     Returns:
 
@@ -29,4 +31,5 @@ def upsert(exported_compressed_file):
     Returns:
 
     """
-    return exported_compressed_file.save()
+    exported_compressed_file.save()
+    return exported_compressed_file
