@@ -52,14 +52,16 @@ class JsonExporter(AbstractExporter):
                 transform_result_content.content_converted = json.dumps(
                     transformed_content, indent=4, ensure_ascii=False
                 )
-            except:
+            except Exception:
                 transform_result_content.content_converted = json.dumps(
                     transformed_content, indent=4
                 )
 
             transform_result_content.content_extension = self.extension
             # add the content to the list of content
-            transform_result.transform_result_content.append(transform_result_content)
+            transform_result.transform_result_content.append(
+                transform_result_content
+            )
             # add the result to the list of result
             results_transform.append(transform_result)
         return results_transform
