@@ -72,10 +72,14 @@ class XslExporter(AbstractExporter):
             transform_result_content.file_name = document_name_with_sha
             # sets the content and extension
             dom = XSDTree.transform_to_xml(xml_item.xml_content)
-            transform_result_content.content_converted = str(self.transformation(dom))
+            transform_result_content.content_converted = str(
+                self.transformation(dom)
+            )
             transform_result_content.content_extension = self.extension
             # add the content to the list of content
-            transform_result.transform_result_content.append(transform_result_content)
+            transform_result.transform_result_content.append(
+                transform_result_content
+            )
             # add the result to the list of result
             results_transform.append(transform_result)
         return results_transform
