@@ -1,12 +1,10 @@
 """ System API for Exported files.
 """
-from datetime import timedelta
-
-from django.utils import timezone
 
 from core_exporters_app.components.exported_compressed_file.models import (
     ExportedCompressedFile,
 )
+from core_main_app.utils.datetime import datetime_now, datetime_timedelta
 
 
 def get_older_exported_files(seconds):
@@ -19,6 +17,6 @@ def get_older_exported_files(seconds):
         exported_file
         for exported_file in ExportedCompressedFile.objects.all()
         if exported_file.creation_date
-        < timezone.now() - timedelta(seconds=seconds)
+        < datetime_now() - datetime_timedelta(seconds=seconds)
     ]
     return exported_files
