@@ -1,6 +1,7 @@
 """Integration tests for exporter rest api
 """
 
+from django.contrib.auth.models import AnonymousUser
 from django.test import override_settings
 
 from core_main_app.access_control.exceptions import AccessControlError
@@ -11,6 +12,9 @@ from core_main_app.utils.tests_tools.MockUser import create_mock_user
 from core_exporters_app.components.exported_compressed_file import (
     api as exported_compressed_file_api,
 )
+from core_exporters_app.components.exported_compressed_file.models import (
+    ExportedCompressedFile,
+)
 from tests.components.exported_compressed_file.fixtures.fixtures import (
     ExportedCompressedFileFixtures,
 )
@@ -39,15 +43,18 @@ class TestGetByExportedCompressedFile(MongoIntegrationBaseTestCase):
                 self.fixture.exported_compressed_file_1.id, None
             )
 
-    # FIXME: add this test
-    # @override_settings(CAN_ANONYMOUS_ACCESS_PUBLIC_DOCUMENT=True)
-    # def test_get_exported_compressed_file_returns_object_if_owner_is_none(self):
-    # """ test_get_exported_compressed_file_returns_object_if_owner_is_none """
+    @override_settings(CAN_ANONYMOUS_ACCESS_PUBLIC_DOCUMENT=True)
+    def test_get_exported_compressed_file_returns_object_if_owner_is_none(
+        self,
+    ):
+        """test_get_exported_compressed_file_returns_object_if_owner_is_none"""
 
-    #     # Act
-    #     result = exported_compressed_file_api.get_by_id(self.fixture.exported_compressed_file_3.id, None)
-    #     # Assert
-    #     self.assertEqual(result, self.fixture.exported_compressed_file_3)
+        # Act
+        result = exported_compressed_file_api.get_by_id(
+            self.fixture.exported_compressed_file_3.id, None
+        )
+        # Assert
+        self.assertEqual(result, self.fixture.exported_compressed_file_3)
 
     @override_settings(CAN_ANONYMOUS_ACCESS_PUBLIC_DOCUMENT=False)
     def test_get_exported_compressed_file_if_owner_is_none_raises_access_control_error_with_setting_false(
@@ -75,21 +82,20 @@ class TestGetByExportedCompressedFile(MongoIntegrationBaseTestCase):
                 self.fixture.exported_compressed_file_1.id, user
             )
 
-    # FIXME: add this test
-    # @override_settings(CAN_ANONYMOUS_ACCESS_PUBLIC_DOCUMENT=True)
-    # def test_get_exported_compressed_file_as_anonymous_returns_object_if_owner_is_none(self):
-    # """ test_get_exported_compressed_file_as_anonymous_returns_object_if_owner_is_none """
+    @override_settings(CAN_ANONYMOUS_ACCESS_PUBLIC_DOCUMENT=True)
+    def test_get_exported_compressed_file_as_anonymous_returns_object_if_owner_is_none(
+        self,
+    ):
+        """test_get_exported_compressed_file_as_anonymous_returns_object_if_owner_is_none"""
 
-    #     # Arrange
-    #     user = create_mock_user(None, is_anonymous=True)
-    #
-    #     # Act
-    #     result = exported_compressed_file_api.get_by_id(self.fixture.exported_compressed_file_3.id, user)
-    #
-    #     # Assert
-    #     self.assertEqual(result, self.fixture.exported_compressed_file_3)
+        # Act
+        result = exported_compressed_file_api.get_by_id(
+            self.fixture.exported_compressed_file_3.id, AnonymousUser()
+        )
+
+        # Assert
+        self.assertEqual(result, self.fixture.exported_compressed_file_3)
 
-    @override_settings(CAN_ANONYMOUS_ACCESS_PUBLIC_DOCUMENT=False)
     def test_get_exported_compressed_file_as_anonymous_raises_access_control_error_with_setting_false(
         self,
     ):
@@ -104,7 +110,9 @@ class TestGetByExportedCompressedFile(MongoIntegrationBaseTestCase):
                 self.fixture.exported_compressed_file_3.id, user
             )
 
-    def test_get_exported_compressed_file_not_owner_raises_access_control_error(self):
+    def test_get_exported_compressed_file_not_owner_raises_access_control_error(
+        self,
+    ):
         """test_get_exported_compressed_file_not_owner_raises_access_control_error"""
 
         # Arrange
@@ -143,3 +151,47 @@ class TestGetByExportedCompressedFile(MongoIntegrationBaseTestCase):
 
         # Assert
         self.assertEqual(result, self.fixture.exported_compressed_file_2)
+
+
+class TestUpsertExportedCompressedFile(MongoIntegrationBaseTestCase):
+    """Test Upsert Exported Compressed File"""
+
+    fixture = fixture_data
+
+    def setUp(self):
+        """setUp"""
+
+        super().setUp()
+
+    def test_upsert_creates_exported_compressed_file(
+        self,
+    ):
+        """test_upsert_creates_exported_compressed_file"""
+
+        exported_compressed_file = ExportedCompressedFile(
+            file_name="exported_compressed_file_1",
+            mime_type="application/zip",
+            is_ready=True,
+            user_id="1",
+        )
+        # Act
+        result = exported_compressed_file_api.upsert(exported_compressed_file)
+
+        # Assert
+        self.assertIsInstance(result, ExportedCompressedFile)
+
+    def test_upsert_updates_exported_compressed_file(
+        self,
+    ):
+        """test_upsert_updates_exported_compressed_file"""
+        # Arrange
+        self.fixture.exported_compressed_file_1.file_name = "new_file_name"
+        # Act
+        result = exported_compressed_file_api.upsert(
+            self.fixture.exported_compressed_file_1
+        )
+
+        # Assert
+        self.assertEqual(
+            result.file_name, self.fixture.exported_compressed_file_1.file_name
+        )
