@@ -1,6 +1,8 @@
 """ Fixture files for Exporters
 """
-from core_main_app.utils.integration_tests.fixture_interface import FixtureInterface
+from core_main_app.utils.integration_tests.fixture_interface import (
+    FixtureInterface,
+)
 
 import core_exporters_app.commons.constants as constants
 from core_exporters_app.components.exporter.models import Exporter
